==> kit-vue-1.16.12.tgz: package/src/stories/ShPhotosGrid.stories.js <==
/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
  number,
} from '@storybook/addon-knobs';


import ShPhotosGrid from '../components/sh-photos-grid/ShPhotosGrid.vue'
import centered from "@storybook/addon-centered";
import axios from 'axios';

const stories = storiesOf('Photos grid', module);
const photosList = [];
for (let i = 0; i < 15; i++) {
  photosList.push({
    id: i,
    is_main_image: i === 4 ? true : false,
    url: 'https://picsum.photos/640?image=' + i,
    alt: 'alt param'
  });
}
const imageTmp = [];
const dropdownOptions = [
  {
    value: 'set_main_image', label: 'Set main image', hideOnFirst: true,
  },
  {
    value: 'edit', label: 'Edit', hideOnFirst: false,
  },
  {
    value: 'delete', label: 'Delete', hideOnFirst: false,
  }
];

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('ShPhotosGrid', () => ({
  components: {ShPhotosGrid },
  data: () => {
    return {
      imageTmp: imageTmp,
      dropdownOptions: dropdownOptions,
      showDropdown: boolean('showDropdown', true),
      photosList: photosList,
      defaultPhotos: boolean('defaultPhotos', true),
      draggable: boolean('draggable', true),
    }
  },
  template: `
<div>
  <ShPhotosGrid
    :dropdownOptions="showDropdown ? dropdownOptions : []"
    :imageTmp="imageTmp"
    :photos="defaultPhotos ? photosList : []"
    :draggable="draggable"
    @onUpload="uploadFiles"
    @imageAction="imageAction"
  ></ShPhotosGrid>
  </div>
      `,
  methods: {
    imageAction: action('imageAction'),
    uploadFiles: files => {
      action('uploadFiles');
      setTimeout(() => {
      files.forEach((item, index) => {
        imageTmp.push('https://picsum.photos/640?image=' + (Number(index)+1) * Math.floor(Math.random() * 10));
      });
      }, 2000)
    },

  }
}),{
  notes: 'A very simple component',
});

==> kit-vue-2.3.8.tgz: package/src/stories/ShPhotosGrid.stories.js <==
/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
  number,
} from '@storybook/addon-knobs';


import ShPhotosGrid from '../components/sh-photos-grid/ShPhotosGrid.vue'
import centered from "@storybook/addon-centered";
import axios from 'axios';

const stories = storiesOf('Photos grid', module);
const photosList = [];
for (let i = 0; i < 15; i++) {
  photosList.push({
    id: i,
    is_main_image: i === 4 ? true : false,
    url: 'https://picsum.photos/640?image=' + i,
    alt: 'alt param'
  });
}
const imageTmp = [];
const dropdownOptions = [
  {
    value: 'set_main_image', label: 'Set main image', hideOnFirst: true,
  },
  {
    value: 'edit', label: 'Edit', hideOnFirst: false,
  },
  {
    value: 'delete', label: 'Delete', hideOnFirst: false,
  }
];

stories.addDecorator(withKnobs);
stories.addDecorator(centered);
stories.add('ShPhotosGrid', () => ({
  components: {ShPhotosGrid },
  props: {
    imageTmp: { default: imageTmp },
    dropdownOptions: { default: dropdownOptions },
    showDropdown: { default: boolean('showDropdown', true) },
    photosList: { default: photosList },
    defaultPhotos: { default: boolean('defaultPhotos', true) },
    draggable: { default: boolean('draggable', true) },
  },
  template: `
<div>
  <ShPhotosGrid
    :dropdownOptions="showDropdown ? dropdownOptions : []"
    :imageTmp="imageTmp"
    :photos="defaultPhotos ? photosList : []"
    :draggable="draggable"
    @onUpload="uploadFiles"
    @imageAction="imageAction"
  ></ShPhotosGrid>
  </div>
      `,
  methods: {
    imageAction: action('imageAction'),
    uploadFiles: files => {
      action('uploadFiles');
      setTimeout(() => {
      files.forEach((item, index) => {
        imageTmp.push('https://picsum.photos/640?image=' + (Number(index)+1) * Math.floor(Math.random() * 10));
      });
      }, 2000)
    },

  }
}),{
  notes: 'A very simple component',
});
